@@ -672,7 +672,7 @@ class ConsumerThread(Thread):
 
             except Exception:
                 logger.exception('Exception: Lost Connection during Fetch in Consumer Thread')
-                self.amqpconn.connection()
+                self.amqpconn.connect()
 #===========================================================================
 class PublisherThread(Thread):
     """
