@@ -130,6 +130,8 @@ class QAMServer:
                server_id='testqamserver',
                serializer='pickle',
                ssl=False):
+    self.consumer = None
+    self.publisher_thread = None
 
     """
     Initially the amqp-connection, a consumer and a publisher-thread are being created.
@@ -406,8 +408,13 @@ class PublisherThread(Thread):
                             routing_key=routing_key,
                             serializer=self.serializer)
       logger.debug('created Publisher')
-      publisher.send(result_record['result_message'])
-      logger.debug('sent message: %s' % repr(result_record['result_message']))
+      try:
+        publisher.send(result_record['result_message'])
+        logger.debug('sent message: %s' % repr(result_record['result_message']))
+      except Exception:
+         logger.exception('Exception: Connection lost during send')
+         self.result_queue.insert(0, result_record)
+         self.amqpconn.connect()
       publisher.close()
       logger.debug('publisher closed')
 
