@@ -816,14 +816,14 @@ class  QamTestCase(unittest.TestCase):
 
 
 if __name__ == '__main__':
-#    unittest.main()
-    result = unittest.TestResult()
-    test = QamTestCase('test_basic_method_call')
-    test.run(result)
-    if len(result.failures) != 0: print "=============== Failures ==========================="
-    print "".join("%s = %s" % (a, b) for a, b in result.failures)
-    if len(result.errors) != 0: print "=============== Errors ============================="
-    print "".join("%s = %s" % (a, b) for a, b in result.errors)
-    print "===================================================="
-    if result.wasSuccessful(): print 'Successfully passed all Tests'
-    else: print "Failed - Details see above."
+    unittest.main()
+#    result = unittest.TestResult()
+#    test = QamTestCase('test_basic_method_call')
+#    test.run(result)
+#    if len(result.failures) != 0: print "=============== Failures ==========================="
+#    print "".join("%s = %s" % (a, b) for a, b in result.failures)
+#    if len(result.errors) != 0: print "=============== Errors ============================="
+#    print "".join("%s = %s" % (a, b) for a, b in result.errors)
+#    print "===================================================="
+#    if result.wasSuccessful(): print 'Successfully passed all Tests'
+#    else: print "Failed - Details see above."
